@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -28,8 +28,6 @@ SCHEMAS_DIR = CONFIG_PATH / "schemas"
 DEFAULT_SERVICE_CONFIG_FILE = "service.yaml"
 SERVICE = "service"
 SERVICES = "services"
-HANDLERS = "handlers"
-CLASS_NAME = "class_name"
 INIT_PY = "__init__.py"
 PYCACHE = "__pycache__"
 
