@@ -607,14 +607,18 @@ class TestAbstractRoundBehaviour:
                 mock_try_fix.assert_not_called()
 
 
-def test_meta_round_behaviour_when_instance_not_subclass_of_abstract_round_behaviour() -> None:
+def test_meta_round_behaviour_when_instance_not_subclass_of_abstract_round_behaviour() -> (
+    None
+):
     """Test instantiation of meta class when instance not a subclass of abstract round behaviour."""
 
     class MyRoundBehaviour(metaclass=_MetaRoundBehaviour):
         pass
 
 
-def test_abstract_round_behaviour_instantiation_without_attributes_raises_error() -> None:
+def test_abstract_round_behaviour_instantiation_without_attributes_raises_error() -> (
+    None
+):
     """Test that definition of concrete subclass of AbstractRoundBehavior without attributes raises error."""
     with pytest.raises(ABCIAppInternalError):
 
@@ -756,5 +760,7 @@ def test_reset_should_be_performed_when_tm_unhealthy() -> None:
         "reset_tendermint_with_wait",
         side_effect=dummy_reset_tendermint_with_wait,
     ) as mock_reset_tendermint:
+        assert behaviour.tm_manager is not None
+        behaviour.tm_manager.gentle_reset_attempted = True
         behaviour.act()
         mock_reset_tendermint.assert_called()
