@@ -27,7 +27,18 @@ from abc import ABC
 from datetime import datetime
 from enum import Enum
 from pathlib import Path
-from typing import Any, Callable, Dict, Generator, Optional, Tuple, Type, Union, cast
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 from unittest import mock
 from unittest.mock import MagicMock
 
@@ -52,6 +63,7 @@ from packages.valory.protocols.ipfs import IpfsMessage
 from packages.valory.protocols.ipfs.dialogues import IpfsDialogue
 from packages.valory.protocols.ledger_api.custom_types import (
     SignedTransaction,
+    SignedTransactions,
     TransactionDigest,
     TransactionDigests,
 )
@@ -258,6 +270,26 @@ def test_async_behaviour_wait_for_message_raises_timeout_exception() -> None:
         try_send(gen)
 
 
+def test_async_behaviour_wait_for_message_raises_timeout_exception_when_no_message() -> (
+    None
+):
+    """Test 'wait_for_message' when it raises TimeoutException."""
+
+    with pytest.raises(TimeoutException):
+        behaviour = AsyncBehaviourTest()
+        behaviour.act()
+        gen = behaviour.wait_for_message(lambda _: False, timeout=0.01)
+        # simulate the generator is waiting for a message
+        behaviour._AsyncBehaviour__generator_act = gen  # type: ignore
+        behaviour._AsyncBehaviour__state = AsyncBehaviour.AsyncState.WAITING_MESSAGE  # type: ignore
+        # the message never arrives, a timeout exception should be raised
+        behaviour.act()
+        # sleep so to run out the timeout
+        time.sleep(0.02)
+        # trigger function and make the exception to raise
+        behaviour.act()
+
+
 def test_async_behaviour_wait_for_condition() -> None:
     """Test 'wait_for_condition' method."""
 
@@ -1249,29 +1281,52 @@ class TestBaseBehaviour:
             self.behaviour._send_transaction_signing_request(MagicMock(), MagicMock())
 
     @pytest.mark.parametrize(
-        "use_flashbots, expected_kwargs",
+        "use_flashbots, target_block_numbers, expected_kwargs",
         (
             (
                 True,
+                None,
                 dict(
                     counterparty=LEDGER_API_ADDRESS,
                     performative=LedgerApiMessage.Performative.SEND_SIGNED_TRANSACTIONS,
-                    signed_transactions=["test_tx"],
-                    kwargs=LedgerApiMessage.Kwargs({"target_blocks": 40}),
+                    signed_transactions=SignedTransactions(
+                        ledger_id="ethereum_flashbots",
+                        signed_transactions=[{"test_tx": "test_tx"}],
+                    ),
+                    kwargs=LedgerApiMessage.Kwargs({}),
+                ),
+            ),
+            (
+                True,
+                [1, 2, 3],
+                dict(
+                    counterparty=LEDGER_API_ADDRESS,
+                    performative=LedgerApiMessage.Performative.SEND_SIGNED_TRANSACTIONS,
+                    signed_transactions=SignedTransactions(
+                        ledger_id="ethereum_flashbots",
+                        signed_transactions=[{"test_tx": "test_tx"}],
+                    ),
+                    kwargs=LedgerApiMessage.Kwargs({"target_block_numbers": [1, 2, 3]}),
                 ),
             ),
             (
                 False,
+                None,
                 dict(
                     counterparty=LEDGER_API_ADDRESS,
                     performative=LedgerApiMessage.Performative.SEND_SIGNED_TRANSACTION,
-                    signed_transaction="test_tx",
+                    signed_transaction=SignedTransaction(
+                        ledger_id="ethereum", body={"test_tx": "test_tx"}
+                    ),
                 ),
             ),
         ),
     )
     def test_send_transaction_request(
-        self, use_flashbots: bool, expected_kwargs: Any
+        self,
+        use_flashbots: bool,
+        target_block_numbers: Optional[List[int]],
+        expected_kwargs: Any,
     ) -> None:
         """Test '_send_transaction_request'."""
         with mock.patch.object(
@@ -1279,13 +1334,12 @@ class TestBaseBehaviour:
             "create",
             return_value=(MagicMock(), MagicMock()),
         ) as create_mock:
-            target_block_numbers = (
-                expected_kwargs["kwargs"].body["target_blocks"]
-                if use_flashbots
-                else None
-            )
             self.behaviour._send_transaction_request(
-                MagicMock(signed_transaction="test_tx"),
+                MagicMock(
+                    signed_transaction=SignedTransaction(
+                        ledger_id="ethereum", body={"test_tx": "test_tx"}
+                    )
+                ),
                 use_flashbots,
                 target_block_numbers,
             )
@@ -1484,6 +1538,7 @@ class TestBaseBehaviour:
     @pytest.mark.parametrize(
         "message, expected_rpc_status",
         (
+            ("Simulation failed for bundle", RPCResponseStatus.SIMULATION_FAILED),
             ("replacement transaction underpriced", RPCResponseStatus.UNDERPRICED),
             ("nonce too low", RPCResponseStatus.INCORRECT_NONCE),
             ("insufficient funds", RPCResponseStatus.INSUFFICIENT_FUNDS),
@@ -2170,6 +2225,12 @@ class TestBaseBehaviour:
                 self.behaviour.context.params.tendermint_com_url + "/hard_reset",
                 parameters=expected_parameters,
             )
+
+            should_be_healthy = isinstance(reset_response, dict) and reset_response.get(
+                "status", False
+            )
+            assert self.behaviour._is_healthy is should_be_healthy
+
             # perform the last iteration which also returns the result
             try:
                 next(reset)
@@ -2191,6 +2252,7 @@ class TestBaseBehaviour:
                         tm_recovery_params.reset_from_round
                         == self.behaviour.matching_round.auto_round_id()
                     )
+                    assert not self.behaviour._is_healthy
             else:
                 pytest.fail("`reset_tendermint_with_wait` did not finish!")
 
@@ -2289,6 +2351,7 @@ class TestTmManager:
         ):
             self.tm_manager.act_wrapper()
 
+    @given(latest_block_height=st.integers(min_value=0))
     @pytest.mark.parametrize(
         "acn_communication_success",
         (
@@ -2296,6 +2359,13 @@ class TestTmManager:
             False,
         ),
     )
+    @pytest.mark.parametrize(
+        "gentle_reset_attempted",
+        (
+            True,
+            False,
+        ),
+    )
     @pytest.mark.parametrize(
         ("tm_reset_success", "num_active_peers"),
         [
@@ -2307,17 +2377,40 @@ class TestTmManager:
     )
     def test_handle_unhealthy_tm(
         self,
+        latest_block_height: int,
         acn_communication_success: bool,
+        gentle_reset_attempted: bool,
         tm_reset_success: bool,
         num_active_peers: Optional[int],
     ) -> None:
         """Test _handle_unhealthy_tm."""
 
+        self.tm_manager.gentle_reset_attempted = gentle_reset_attempted
+        self.tm_manager.context.state.round_sequence.height = latest_block_height
+
         def mock_sleep(_seconds: int) -> Generator:
             """A method that mocks sleep."""
             return
             yield
 
+        def dummy_do_request(*_: Any) -> Generator[None, None, MagicMock]:
+            """Dummy `_do_request` method."""
+            yield
+            return mock.MagicMock()
+
+        def dummy_get_status(*_: Any) -> Generator[None, None, MagicMock]:
+            """Dummy `_get_status` method."""
+            yield
+            return mock.MagicMock(
+                body=json.dumps(
+                    {
+                        "result": {
+                            "sync_info": {"latest_block_height": latest_block_height}
+                        }
+                    }
+                ).encode()
+            )
+
         gen = self.tm_manager._handle_unhealthy_tm()
         with mock.patch.object(
             self.tm_manager,
@@ -2329,30 +2422,39 @@ class TestTmManager:
             side_effect=yield_and_return_int_wrapper(num_active_peers),
         ), mock.patch.object(
             self.tm_manager, "sleep", side_effect=mock_sleep
-        ), mock.patch(
-            "sys.exit"
-        ) as mock_sys_exit, mock.patch.object(
+        ), mock.patch.object(
             BaseBehaviour,
             "request_recovery_params",
             side_effect=dummy_generator_wrapper(acn_communication_success),
-        ):
-            next(gen)
+        ), mock.patch.object(
+            BaseBehaviour, "_do_request", new_callable=lambda *_: dummy_do_request
+        ), mock.patch.object(
+            BaseBehaviour, "_get_status", new_callable=lambda *_: dummy_get_status
+        ), mock.patch.object(
+            self.tm_manager.round_sequence, "set_block_stall_deadline"
+        ) as set_block_stall_deadline_mock:
             next(gen)
 
+            if not gentle_reset_attempted:
+                next(gen)
+                assert self.tm_manager.gentle_reset_attempted
+                with pytest.raises(StopIteration):
+                    next(gen)
+                set_block_stall_deadline_mock.assert_called_once()
+                assert not self.tm_manager.gentle_reset_attempted
+                return
+
             if not acn_communication_success:
                 with pytest.raises(StopIteration):
                     next(gen)
+                set_block_stall_deadline_mock.assert_not_called()
                 return
 
             next(gen)
             with pytest.raises(StopIteration):
                 next(gen)
 
-            if (
-                num_active_peers is not None
-                and num_active_peers < self._DUMMY_CONSENSUS_THRESHOLD
-            ):
-                mock_sys_exit.assert_called()
+            set_block_stall_deadline_mock.assert_not_called()
 
     @pytest.mark.parametrize(
         "expected_reset_params",
