@@ -18,18 +18,20 @@
 # ------------------------------------------------------------------------------
 
 """This module contains utility functions for the 'abstract_round_abci' skill."""
+
 import builtins
 import collections
 import dataclasses
 import sys
 import types
 import typing
-from decimal import Decimal
 from hashlib import sha256
+from math import ceil
 from typing import (
     Any,
     Dict,
     FrozenSet,
+    Iterator,
     List,
     Optional,
     Set,
@@ -47,7 +49,7 @@ from py_ecc.bls import G2Basic as bls
 from typing_extensions import Literal, TypeGuard, TypedDict
 
 
-MAX_UINT64 = 2 ** 64 - 1
+MAX_UINT64 = 2**64 - 1
 DEFAULT_TENDERMINT_P2P_PORT = 26656
 
 
@@ -123,17 +125,6 @@ class VerifyDrand:  # pylint: disable=too-few-public-methods
         return True, None
 
 
-def to_int(most_voted_estimate: float, decimals: int) -> int:
-    """Convert to int."""
-    most_voted_estimate_ = str(most_voted_estimate)
-    decimal_places = most_voted_estimate_[::-1].find(".")
-    if decimal_places > decimals:
-        most_voted_estimate_ = most_voted_estimate_[: -(decimal_places - decimals)]
-    most_voted_estimate_decimal = Decimal(most_voted_estimate_)
-    int_value = int(most_voted_estimate_decimal * (10 ** decimals))
-    return int_value
-
-
 def get_data_from_nested_dict(
     nested_dict: Dict, keys: str, separator: str = ":"
 ) -> Any:
@@ -416,7 +407,7 @@ def check_dataclass(value: Any, ty: Type[Any]) -> Result:
     return None
 
 
-def check_typeddict(value: Any, ty: Type[Type[Any]]) -> Result:
+def check_typeddict(value: Any, ty: Type[Any]) -> Result:
     """Check typeddict type."""
     if not isinstance(value, dict):
         return AutonomyTypeError(ty, value)  # pragma: no cover
@@ -462,3 +453,36 @@ def check_type(name: str, value: Any, type_hint: Any) -> None:
     if err is not None:
         err.path.append(name)
         raise err
+
+
+def is_primitive_or_none(obj: Any) -> bool:
+    """Checks if the given object is a primitive type or `None`."""
+    primitives = (bool, int, float, str)
+    return isinstance(obj, primitives) or obj is None
+
+
+def is_json_serializable(obj: Any) -> bool:
+    """Checks if the given object is json serializable."""
+    if isinstance(obj, (tuple, list)):
+        return all(is_json_serializable(x) for x in obj)
+    if isinstance(obj, dict):
+        return all(
+            is_primitive_or_none(k) and is_json_serializable(v) for k, v in obj.items()
+        )
+
+    return is_primitive_or_none(obj)
+
+
+def filter_negative(mapping: Dict[str, int]) -> Iterator[str]:
+    """Return the keys of a dictionary for which the values are negative integers."""
+    return (key for key, number in mapping.items() if number < 0)
+
+
+def consensus_threshold(nb: int) -> int:
+    """
+    Get consensus threshold.
+
+    :param nb: the number of participants
+    :return: the consensus threshold
+    """
+    return ceil((2 * nb + 1) / 3)
