@@ -29,7 +29,9 @@ from unittest.mock import patch
 
 from aea.test_tools.test_skill import BaseSkillTestCase
 
-from packages.valory.connections.abci.connection import PUBLIC_ID
+from packages.valory.connections.abci.connection import (
+    PUBLIC_ID as ABCI_CONNECTION_PUBLIC_ID,
+)
 from packages.valory.protocols.abci.custom_types import (
     CheckTxType,
     CheckTxTypeEnum,
@@ -38,10 +40,18 @@ from packages.valory.protocols.abci.custom_types import (
     ValidatorUpdates,
 )
 from packages.valory.protocols.abci.message import AbciMessage
+from packages.valory.skills.counter import PUBLIC_ID
 from packages.valory.skills.counter.dialogues import AbciDialogue, AbciDialogues
 from packages.valory.skills.counter.handlers import ABCICounterHandler
 
 
+def test_skill_public_id() -> None:
+    """Test skill module public ID"""
+
+    assert PUBLIC_ID.name == Path(__file__).parents[1].name
+    assert PUBLIC_ID.author == Path(__file__).parents[3].name
+
+
 PACKAGE_DIR = Path(__file__).parent.parent
 OK_CODE = 0
 ERROR_CODE = 1
@@ -79,9 +89,10 @@ class TestCounterHandler(BaseSkillTestCase):
         """Test the setup method of the echo handler."""
         with patch.object(self.logger, "log") as mock_logger:
             self.abci_counter_handler.setup()
-            mock_logger.assert_any_call(
-                logging.DEBUG, f"ABCI Handler: setup method called. Using {PUBLIC_ID}."
+            expected = (
+                f"ABCI Handler: setup method called. Using {ABCI_CONNECTION_PUBLIC_ID}."
             )
+            mock_logger.assert_any_call(logging.DEBUG, expected)
 
         # after
         self.assert_quantity_in_outbox(0)
