@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@
 """Test the rounds of the skill."""
 
 from copy import deepcopy
-from typing import FrozenSet
 
 from packages.valory.skills.abstract_round_abci.base import BaseSynchronizedData
 from packages.valory.skills.abstract_round_abci.test_tools.rounds import (
@@ -35,14 +34,6 @@ from packages.valory.skills.register_reset_recovery_abci.rounds import (
 )
 
 
-MAX_PARTICIPANTS: int = 4
-
-
-def get_participants() -> FrozenSet[str]:
-    """Participants"""
-    return frozenset([f"agent_{i}" for i in range(MAX_PARTICIPANTS)])
-
-
 class BaseRoundTestClass(
     ExternalBaseRoundTestClass
 ):  # pylint: disable=too-few-public-methods
@@ -62,7 +53,6 @@ class TestTerminationRound(BaseRoundTestClass):
 
         test_round = RoundCountRound(
             synchronized_data=deepcopy(self.synchronized_data),
-            consensus_params=self.consensus_params,
         )
         payload_data = 1
         first_payload, *payloads = [
