@@ -21,6 +21,7 @@
 
 # pylint: skip-file
 
+import hashlib
 import logging  # noqa: F401
 from typing import Dict, FrozenSet
 
@@ -36,7 +37,7 @@ from packages.valory.skills.reset_pause_abci.rounds import ResetAndPauseRound
 
 
 MAX_PARTICIPANTS: int = 4
-DUMMY_RANDOMNESS = 0.1  # for coverage purposes
+DUMMY_RANDOMNESS = hashlib.sha256("hash".encode() + str(0).encode()).hexdigest()
 
 
 def get_participant_to_period_count(
@@ -61,9 +62,11 @@ class TestResetAndPauseRound(BaseCollectSameUntilThresholdRoundTest):
         """Runs tests."""
 
         synchronized_data = self.synchronized_data.update(
-            keeper_randomness=DUMMY_RANDOMNESS, consensus_threshold=3
+            most_voted_randomness=DUMMY_RANDOMNESS, consensus_threshold=3
+        )
+        synchronized_data._db._cross_period_persisted_keys = frozenset(
+            {"most_voted_randomness"}
         )
-        synchronized_data._db._cross_period_persisted_keys = {"keeper_randomness"}
         test_round = ResetAndPauseRound(synchronized_data=synchronized_data)
         next_period_count = 1
         self._complete_run(
@@ -72,11 +75,7 @@ class TestResetAndPauseRound(BaseCollectSameUntilThresholdRoundTest):
                 round_payloads=get_participant_to_period_count(
                     self.participants, next_period_count
                 ),
-                synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.create(
-                    participants=[tuple(self.participants)],
-                    all_participants=[tuple(self.participants)],
-                    keeper_randomness=[DUMMY_RANDOMNESS],
-                ),
+                synchronized_data_update_fn=lambda _synchronized_data, _: _synchronized_data.create(),
                 synchronized_data_attr_checks=[],  # [lambda _synchronized_data: _synchronized_data.participants],
                 most_voted_payload=next_period_count,
                 exit_event=self._event_class.DONE,
