@@ -99,6 +99,7 @@ def hash_payload_to_hex(  # pylint: disable=too-many-arguments, too-many-locals
     safe_gas_price: int = 0,
     gas_token: str = NULL_ADDRESS,
     refund_receiver: str = NULL_ADDRESS,
+    use_flashbots: bool = False,
 ) -> str:
     """Serialise to a hex string."""
     if len(safe_tx_hash) != 64:  # should be exactly 32 bytes!
@@ -122,11 +123,17 @@ def hash_payload_to_hex(  # pylint: disable=too-many-arguments, too-many-locals
     if operation not in [v.value for v in SafeOperation]:
         raise ValueError("SafeOperation value is not valid")  # pragma: nocover
 
+    if not isinstance(use_flashbots, bool):
+        raise ValueError(
+            f"`use_flashbots` value ({use_flashbots}) is not valid. A boolean value was expected instead"
+        )
+
     ether_value_ = ether_value.to_bytes(32, "big").hex()
     safe_tx_gas_ = safe_tx_gas.to_bytes(32, "big").hex()
     operation_ = operation.to_bytes(1, "big").hex()
     base_gas_ = base_gas.to_bytes(32, "big").hex()
     safe_gas_price_ = safe_gas_price.to_bytes(32, "big").hex()
+    use_flashbots_ = use_flashbots.to_bytes(32, "big").hex()
 
     concatenated = (
         safe_tx_hash
@@ -138,6 +145,7 @@ def hash_payload_to_hex(  # pylint: disable=too-many-arguments, too-many-locals
         + safe_gas_price_
         + gas_token
         + refund_receiver
+        + use_flashbots_
         + data.hex()
     )
     return concatenated
@@ -157,6 +165,7 @@ def skill_input_hex_to_payload(payload: str) -> dict:
         safe_gas_price=int.from_bytes(bytes.fromhex(payload[300:364]), "big"),
         gas_token=payload[364:406],
         refund_receiver=payload[406:448],
-        data=bytes.fromhex(payload[448:]),
+        use_flashbots=bool.from_bytes(bytes.fromhex(payload[448:512]), "big"),
+        data=bytes.fromhex(payload[512:]),
     )
     return tx_params
