@@ -49,9 +49,13 @@ PACKAGE_TYPE_REGEX = (
 AEA_COMMAND_REGEX = rf"(?P<full_cmd>{CLI_REGEX} {CMD_REGEX} (?:{VENDOR_REGEX}\/{PACKAGE_REGEX}:{VERSION_REGEX}?:?)?(?P<hash>{IPFS_HASH_REGEX}){FLAGS_REGEX})"
 FULL_PACKAGE_REGEX = rf"(?P<full_package>(?:{VENDOR_REGEX}\/{PACKAGE_REGEX}:{VERSION_REGEX}?:?)?(?P<hash>{IPFS_HASH_REGEX}))"
 PACKAGE_TABLE_REGEX = rf"\|\s*{PACKAGE_TYPE_REGEX}\/{VENDOR_REGEX}\/{PACKAGE_REGEX}\/{VERSION_REGEX}\s*\|\s*`(?P<hash>{IPFS_HASH_REGEX})`\s*\|"
+PACKAGE_MAPPING_REGEX = rf"(?P<package_mapping>(?:\"{PACKAGE_TYPE_REGEX}\/{VENDOR_REGEX}\/{PACKAGE_REGEX}\/{VERSION_REGEX}\":)\s*\"(?P<hash>{IPFS_HASH_REGEX})\")"
 
 ROOT_DIR = Path(__file__).parent.parent
-HASH_SKIPS = ()
+HASH_SKIPS = [
+    "Qmbh9SQLbNRawh9Km3PMEDSxo77k1wib8fYZUdZkhPBiev",  # Testing image used in tutorials/examples.
+    "bafybei0000000000000000000000000000000000000000000000000000",  # Placeholder hash used in tutorials/examples.
+]
 
 
 def read_file(filepath: str) -> str:
@@ -253,9 +257,11 @@ def check_ipfs_hashes(  # pylint: disable=too-many-locals,too-many-statements
     package_manager = PackageHashManager()
     matches = 0
 
-    # Fix full commands in docs
+    # Fix hashes in docs
     for md_file in all_md_files:
         content = read_file(str(md_file))
+
+        # Fix full commands in docs
         for match in [m.groupdict() for m in re.finditer(AEA_COMMAND_REGEX, content)]:
             matches += 1
             doc_full_cmd = match["full_cmd"]
@@ -300,6 +306,44 @@ def check_ipfs_hashes(  # pylint: disable=too-many-locals,too-many-statements
                     f"\tFound: {doc_hash}\n"
                 )
 
+        # Fix package mappings in docs
+        for match in [
+            m.groupdict() for m in re.finditer(PACKAGE_MAPPING_REGEX, content)
+        ]:
+            matches += 1
+            package_mapping = match["package_mapping"]
+            package_hash = match["hash"]
+
+            if package_hash in HASH_SKIPS:
+                continue
+
+            expected_hash = package_manager.get_hash_by_attributes(
+                match["package_type"], match["vendor"], match["package"]
+            )
+
+            if package_hash == expected_hash:
+                continue
+
+            hash_mismatches = True
+
+            if fix:
+                new_package_mapping = package_mapping.replace(
+                    package_hash, expected_hash
+                )
+                content = content.replace(package_mapping, new_package_mapping)
+
+                with open(str(md_file), "w", encoding="utf-8") as qs_file:
+                    qs_file.write(content)
+                print(f"Fixed an IPFS hash in doc file {md_file}")
+                old_to_new_hashes[package_hash] = expected_hash
+            else:
+                print(
+                    f"IPFS hash mismatch in doc file {md_file}.\n"
+                    f"\tMapping string: {package_mapping}\n"
+                    f"\tExpected: {expected_hash}\n"
+                    f"\tFound: {package_hash}\n"
+                )
+
     # Fix packages in python files
     all_py_files = [Path("autonomy", "constants.py")]
     for py_file in all_py_files:
