@@ -139,7 +139,7 @@ lock_packages  # unused function (autonomy/cli/packages.py:33)
 PathArgument  # unused class (autonomy/cli/utils/click_utils.py:91)
 protocol  # unused function (autonomy/cli/develop.py:101)
 local  # unused variable (autonomy/chain/config.py:71)
-custom  # unused variable (autonomy/chain/config.py:77)
+custom_chain  # unused variable (autonomy/chain/config.py:77)
 goerli  # unused variable (autonomy/chain/config.py:83)
 ethereum  # unused variable (autonomy/chain/config.py:89)
 agent_registry  # unused variable (autonomy/chain/config.py:116)
@@ -217,3 +217,6 @@ insert_one  # unused method (open-autonomy/autonomy/analyse/logs/db.py:143)
 _parse_logs  # unused function (open-autonomy/autonomy/cli/analyse.py:165)
 _check_service  # unused function (open-autonomy/autonomy/cli/analyse.py:289)
 get_metavar  # unused method (autonomy/cli/utils/click_utils.py:124)
+_terminate  # unused function (autonomy/cli/service.py:162)
+_unbond  # unused function (autonomy/cli/service.py:186)
+_info  # unused function (autonomy/cli/service.py:210)
