@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -105,7 +105,10 @@ class TestServiceConfig:
         """Test check_overrides_valid method."""
 
         dummy_service = get_dummy_service_config(file_number=2)
-        dummy_service.append(dummy_service[-1])
+        (skill_config,) = [
+            override for override in dummy_service if override.get("type") == "skill"
+        ]
+        dummy_service.append(skill_config)
         self._write_service(dummy_service)
 
         with pytest.raises(
@@ -121,7 +124,7 @@ class TestServiceConfig:
     ) -> None:
         """Test process metadata."""
 
-        _, component_override = get_dummy_service_config(file_number=2)
+        _, component_override, _ = get_dummy_service_config(file_number=2)
         configuration, component_id, has_multiple_overrides = Service.process_metadata(
             component_override.copy()
         )
