@@ -20,8 +20,9 @@
 """Test if constants are valid."""
 
 from pathlib import Path
+from typing import Dict
 
-from aea.cli.packages import PackageManager
+from aea.cli.packages import get_package_manager
 from aea.configurations.data_types import PackageId, PackageType, PublicId
 
 from autonomy.constants import ABSTRACT_ROUND_ABCI_SKILL_WITH_HASH
@@ -29,11 +30,18 @@ from autonomy.constants import ABSTRACT_ROUND_ABCI_SKILL_WITH_HASH
 from tests.conftest import ROOT_DIR
 
 
+def get_hash(key: str) -> Dict[str, str]:
+    """Get packages."""
+    data = get_package_manager(Path(ROOT_DIR, "packages")).json
+    if "dev" in data:
+        return data["dev"][key]
+    return data[key]
+
+
 def test_abstract_round_abci_skill_hash() -> None:
     """Test abstract_round_abci skill public_id constants"""
 
-    package_manager = PackageManager.from_dir(Path(ROOT_DIR, "packages"))
     public_id = PublicId.from_str(ABSTRACT_ROUND_ABCI_SKILL_WITH_HASH)
     package_id = PackageId(PackageType.SKILL, public_id)
 
-    assert public_id.hash == package_manager.packages[package_id]
+    assert public_id.hash == get_hash(package_id.to_uri_path)
