@@ -29,7 +29,8 @@ from tests.conftest import ROOT_DIR
 
 IPFS_HASH_REGEX = r"bafybei[A-Za-z0-9]{52}"
 PYTHON_LINE_COMMENT_REGEX = r"^#.*\n"
-DOC_ELLIPSIS_REGEX = r"\s*#\s...\n"
+DOC_ELLIPSIS_REGEX = r"(\s*#\s*...\s*?\n)|(\s*#\s*\(...\)\s*?\n)"
+YAML_HASH_REGEX = rf":{IPFS_HASH_REGEX}"
 PYTHON_COMMAND = r"^pyt(hon|est) (?P<file_name>.*\.py).*$"
 MAKE_COMMAND = r"^make (?P<cmd_name>.*)$"
 AUTONOMY_COMMAND = r"^(?P<cmd_name>autonomy .*)$"
@@ -44,6 +45,7 @@ class CodeType(Enum):
     YAML = "yaml"
     BASH = "bash"
     NOCODE = "nocode"
+    JSON = "json"
 
 
 def dedent_code(code: str, n_spaces: int) -> str:
@@ -56,11 +58,11 @@ def extract_code_blocks(filepath: str, filter_: Optional[str] = None) -> List[st
     """Extract code blocks from .md files."""
     content = Path(filepath).read_text(encoding="utf-8")
     code_blocks = re.findall(
-        rf"([ \t]*)```{filter_}\n(.+?)[ \t]*```", content, flags=re.DOTALL
+        rf"([ \t]*)```{filter_}(\s*|\s+.*?)\n(.+?)[ \t]*```", content, flags=re.DOTALL
     )
 
     dedented_code_blocks = [
-        dedent_code(code, len(indent)) for indent, code in code_blocks
+        dedent_code(code, len(indent)) for indent, _, code in code_blocks
     ]
     return dedented_code_blocks
 
@@ -93,6 +95,11 @@ def remove_doc_ellipsis(string: str) -> str:
     return re.sub(DOC_ELLIPSIS_REGEX, "", string)
 
 
+def remove_yaml_hashes(string: str) -> str:
+    """Removes YAML ":bafybei..." hashes after a public ID"""
+    return re.sub(YAML_HASH_REGEX, "", string)
+
+
 def remove_ips_hashes(string: str) -> str:
     """Replaces IPFS hashes with a placeholder"""
     return re.sub(IPFS_HASH_REGEX, "<ipfs_hash>", string)
@@ -185,7 +192,6 @@ def check_bash_commands_exist(md_file: str, make_commands: List[str]) -> None:
 
     for code_block in code_blocks:
         for line in code_block.split("\n"):
-
             # Python/pytest commands
             match = re.match(PYTHON_COMMAND, line)
             if match:
